@@ -10,7 +10,10 @@ class ChatAPI:
     # import json
     from sys import path
 
-    def __init__(self, config_file: str = f"{path[0]}/config.json"):
+    def __init__(
+        self, config_file: str = f"{path[0]}/config.json", token_refresh: bool = False
+    ):
+        self.token_refresh = token_refresh
         self.config_file = config_file
         self.config: dict
 
@@ -129,6 +132,9 @@ class ChatAPI:
 
             self.save_config()
 
+            if self.token_refresh:
+                quit()
+
     def get_users(self) -> list[str]:
         import requests
         import json
@@ -197,7 +203,7 @@ class ChatAPI:
 
     def read(
         self,
-        *,
+        /,
         after: int | float | None = 60,
         before: int | float | None = None,
         users: list[str] = None,
@@ -243,15 +249,6 @@ class ChatAPI:
 def token_refresh():
     """
     Gets a new token for your config.json.
-
-    Equivalent to doing `ChatAPI().get_token()`.
     """
 
-    from sys import path
-
-    try:
-        with open(f"{path[0]}/config.json"):
-            pass
-        ChatAPI().get_token()
-    except FileNotFoundError:
-        ChatAPI()
+    ChatAPI(token_refresh=True).get_token()
